AssetResourceLoader

Struct AssetResourceLoader 

pub struct AssetResourceLoader { /* private fields */ }
Re-exports the AVPlayer framework surface for this item.

Implementations

Source

impl AssetResourceLoader

pub fn has_delegate(&self) -> Result<bool, AVPlayerError>

pub fn preloads_eligible_content_keys(&self) -> Result<bool, AVPlayerError>

pub fn set_preloads_eligible_content_keys(&self, enabled: bool)

pub fn sends_common_media_client_data_as_http_headers( &self, ) -> Result<Option<bool>, AVPlayerError>

pub fn set_sends_common_media_client_data_as_http_headers( &self, enabled: bool, ) -> Result<(), AVPlayerError>

pub fn observe_loading_requests<F>( &self, queue_label: Option<&str>, callback: F, ) -> Result<AssetResourceLoaderObserver, AVPlayerError>
where F: Fn(AssetResourceLoaderEvent) -> bool + Send + 'static,

pub fn observe_loading_request_events( &self, queue_label: Option<&str>, capacity: usize, ) -> Result<AssetResourceLoaderEventStream, AVPlayerError>

Returns an async stream of loading-request delegate callbacks.

The underlying delegate returns true for loading and renewal request events so callers can complete those requests asynchronously.

pub fn loading_request_stream( &self, capacity: usize, ) -> Result<AssetResourceLoaderEventStream, AVPlayerError>

Returns an async loading-request stream on the default resource-loader queue label.