Asset

Struct Asset 

pub struct Asset { /* private fields */ }
Re-exports the AVPlayer framework surface for this item. Safe wrapper around AVAsset.

Implementations

Source

impl Asset

pub fn duration(&self) -> Result<Time, AVPlayerError>

Asset duration.

pub fn metadata(&self) -> Result<Vec<MetadataItem>, AVPlayerError>

Static metadata attached to the asset.

pub fn url(&self) -> Result<Option<String>, AVPlayerError>

Asset URL when backed by AVURLAsset.

pub fn status_of_value( &self, key: &str, ) -> Result<KeyValueStatus, AVPlayerError>

Query the current load status of a key without triggering loading.

pub fn load_values_asynchronously<I, S>( &self, keys: I, ) -> Result<Vec<KeyLoadStatus>, AVPlayerError>
where I: IntoIterator<Item = S>, S: AsRef<str>,

Trigger asynchronous loading for the given keys and wait for completion.

pub fn tracks(&self) -> Result<Vec<AssetTrack>, AVPlayerError>

Enumerate all tracks owned by the asset.

Source

impl Asset

Source

impl Asset

Source

impl Asset

Source

impl Asset

Source

impl Asset