AssetDownloadURLSession

Struct AssetDownloadURLSession 

pub struct AssetDownloadURLSession { /* private fields */ }
Re-exports the AVPlayer framework surface for this item.

Implementations

Source

impl AssetDownloadURLSession

pub fn background(identifier: &str) -> Result<Self, AVPlayerError>

pub fn background_with_events( identifier: &str, queue_label: Option<&str>, capacity: usize, ) -> Result<(Self, AssetDownloadDelegateEventStream), AVPlayerError>

Creates a background download session together with an async delegate-event stream.

pub fn background_events( identifier: &str, capacity: usize, ) -> Result<(Self, AssetDownloadDelegateEventStream), AVPlayerError>

Creates a background download session with the default queue choice and an async delegate-event stream.

pub fn background_with_handler<F>( identifier: &str, queue_label: Option<&str>, callback: F, ) -> Result<Self, AVPlayerError>
where F: Fn(AssetDownloadDelegateEvent) + Send + 'static,

pub fn asset_download_task( &self, configuration: &AssetDownloadConfiguration, ) -> Result<AssetDownloadTask, AVPlayerError>

pub fn aggregate_asset_download_task( &self, asset: &UrlAsset, media_selections: &[MediaSelection], title: &str, artwork_data: Option<&[u8]>, ) -> Result<AggregateAssetDownloadTask, AVPlayerError>

pub fn finish_tasks_and_invalidate(&self)

pub fn invalidate_and_cancel(&self)